#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# program/match-regex

# Standardized types do not require authors to specify any control script as
# it can be generated on import. However when provided it will overwrite the
# default behaivior.

import sys
import subprocess
import re


def build(ctx):
    # Add filenames
    allArgs = ['/usr/bin/make']
    #, self.sourcefile, "-o", "%s.exe" % self.sourcefile]

    # start subprocess in with work_path as cwd
    p = subprocess.Popen(allArgs, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=ctx.work_path)
    msgs,errs = p.communicate()
    retval = p.wait()    

    errs = errs.decode("utf-8")
    msgs = msgs.decode("utf-8")

    return retval, errs, msgs


def execute(ctx):
    # if build failed, return early
    if ctx.build_result[0] != 0:
        return

    allArgs = [ctx.programfile]

    p = subprocess.Popen(allArgs, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=ctx.work_path)
    msgs,errs = p.communicate()
    retval = p.wait()    

    errs = errs.decode("utf-8")
    msgs = msgs.decode("utf-8")

    return retval, errs, msgs


def grade(ctx):
    """A function that governs the grading process when different from default.
    Expected is return value that indicates if the task passed or failed."""

    # if build failed, return early and set grade to FAIL
    if ctx.build_result[0] != 0:
        return 'FAIL'

    ctx.execute_result = execute(ctx)

    print(ctx.data['data']['regex'], file=sys.stderr)
    print(ctx.execute_result, file=sys.stderr)
    if re.match(ctx.data['data']['regex'], ctx.execute_result[2]) != None:
        return 'PASS'
    else:
        return 'FAIL'

   

def response(ctx):
    
    output = ""
    if ctx.build_result[0] != 0:
        output = ctx.build_result[1]
    else:
        output = ctx.execute_result[2]

    grade = ctx.grade_result
    msg = ""
    return {'output': output, 'grade': grade, 'msg': msg, 'data': None}
